function v=compute_tangential_surge_e1(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes tangential_surge_e1
% Script automatically generated by fit_tangential_surge_e1.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.27582
% RMSE  = 3.6184
% MEAN  = 9.1186
% RANGE = 5.0782 - 23.0474

beta( 1 )= 6.0901e+00 ;
beta( 2 )= 1.7079e-06 ;
beta( 3 )= 8.5260e+00 ;
beta( 4 )= 1.4105e+00 ;
beta( 5 )= 1.5495e+00 ;

v = beta(1) + beta(2) * exp(-vt/beta(3)) .* w.^beta(4)./cos(phi*pi/180);
